@@ -124,6 +124,9 @@ void geneasydraw(short instance, int mode, objectptr curobj, objinstptr curinst)
       case OBJINST:
          UDrawObject((objinstptr)elementptr, SINGLE, mode, NULL);
          break;
+      case GRAPHIC:
+         UDrawGraphic((graphicptr)elementptr);
+	 break;
    }
 }
 
